<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>MX Snapshot</source>
        <translation>MX momentinė kopija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Snapshot location:</source>
        <translation>Momentinės kopijos vieta:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Panaudota vieta / (šaknies) ir /home skaidiniuose:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Snapshot name:</source>
        <translation>Momentinės kopijos pavadinimas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Select a different snapshot directory</source>
        <translation>Pasirinkti kitą momentinės kopijos katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Downloads</source>
        <translation>Atsiuntimai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Documents</source>
        <translation>Dokumentai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>All of the above</source>
        <translation>Viskas iš aukščiau paminėtų</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Pictures</source>
        <translation>Paveikslai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="276"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Music</source>
        <translation>Muzika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Desktop</source>
        <translation>Darbalaukis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Videos</source>
        <translation>Vaizdo įrašai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Atstatant paskyras (platinimui kitiems žmonėms)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Type of snapshot:</source>
        <translation>Momentinės kopijos tipas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Išsaugant paskyras (asmeninei atsarginei kopijai)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Edit Exclusion File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>lz4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>lzo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <source>gzip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>xz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>ISO compression scheme:</source>
        <translation>ISO glaudinimo schema:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Calculate checksums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Display help </source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>Next</source>
        <translation>Tolesnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <source>Used space on / (root): </source>
        <translation type="vanished">Panaudota vieta / (šaknies) skaidinyje: </translation>
    </message>
    <message>
        <source>Used space on /home: </source>
        <translation type="vanished">Panaudota vieta /home skaidinyje: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Laisva vieta %1 skaidinyje, kuriame yra patalpintas momentinės kopijos aplankas: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="148"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Installing </source>
        <translation>Įdiegiama </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <source>Could not install </source>
        <translation type="vanished">Nepavyko įdiegti</translation>
    </message>
    <message>
        <source>Copying the new-iso filesystem...</source>
        <translation type="vanished">Kopijuojama new-iso failų sistema...</translation>
    </message>
    <message>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">Nepavyko sukurti linuxfs failo, prašome patikrinti ar paskirties skaidinyje yra pakankamai vietos.</translation>
    </message>
    <message>
        <source>Creating CD/DVD image file...</source>
        <translation type="vanished">Kuriamas CD/DVD atvaizdžio failas...</translation>
    </message>
    <message>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">Nepavyko sukurti ISO failo, prašome patikrinti ar paskirties skaidinyje yra pakankamai vietos.</translation>
    </message>
    <message>
        <source>Cleaning...</source>
        <translation type="vanished">Išvaloma...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">Atlikta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>Please wait.</source>
        <translation>Prašome palaukti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Prašome palaukti. Apskaičiuojama panaudota disko vieta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Settings</source>
        <translation>Nuostatos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>Momentinė kopija naudos šiuos nustatymus:*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>- Snapshot directory:</source>
        <translation>- Momentinės kopijos katalogas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>- Kernel to be used:</source>
        <translation>- Bus naudojamas branduolys:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Final chance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>OK to start?</source>
        <translation>Galima pradėti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Could not create temporary directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Output</source>
        <translation>Išvestis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Edit Boot Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="vanished">Pavyko</translation>
    </message>
    <message>
        <source>All finished!</source>
        <translation type="vanished">Viskas užbaigta!</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>About %1</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>%1 License</source>
        <translation>%1 licencija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>%1 Help</source>
        <translation>%1 žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Select Snapshot Directory</source>
        <translation>Pasirinkite momentinės kopijos katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Confirmation</source>
        <translation>Patvirtinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Ar tikrai norite išeiti iš programos?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <location filename="../about.cpp" line="44"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Klaida</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Privalote paleisti šią programą kaip pagrindinis (root) naudotojas.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Use CLI only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Output filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Or the full path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation type="unfinished">Atstatant paskyras (platinimui kitiems žmonėms)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Exclude main folders, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Desktop, Documents, Downloads, Music, Networks, Pictures, Videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>one item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Compression format, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>You must run this program as root.</source>
        <translation type="unfinished">Privalote paleisti šią programą kaip pagrindinis (root) naudotojas.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="121"/>
        <location filename="../main.cpp" line="179"/>
        <source>Error</source>
        <translation type="unfinished">Klaida</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <location filename="../main.cpp" line="122"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>version, or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="180"/>
        <location filename="../settings.cpp" line="209"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <location filename="../main.cpp" line="128"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="55"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="87"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="105"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="202"/>
        <source>Could not find a usable kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="283"/>
        <source>Used space on / (root): </source>
        <translation type="unfinished">Panaudota vieta / (šaknies) skaidinyje: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="286"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="295"/>
        <source>Used space on /home: </source>
        <translation type="unfinished">Panaudota vieta /home skaidinyje: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="347"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation type="unfinished">Laisva vieta %1 skaidinyje, kuriame yra patalpintas momentinės kopijos aplankas: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="349"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="364"/>
        <source>Desktop</source>
        <translation type="unfinished">Darbalaukis</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="365"/>
        <source>Documents</source>
        <translation type="unfinished">Dokumentai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="366"/>
        <source>Downloads</source>
        <translation type="unfinished">Atsiuntimai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="367"/>
        <source>Music</source>
        <translation type="unfinished">Muzika</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="368"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="369"/>
        <source>Pictures</source>
        <translation type="unfinished">Paveikslai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="370"/>
        <source>Videos</source>
        <translation type="unfinished">Vaizdo įrašai</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="115"/>
        <source>Interrupted or failed to complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="35"/>
        <location filename="../work.cpp" line="55"/>
        <location filename="../work.cpp" line="62"/>
        <location filename="../work.cpp" line="68"/>
        <location filename="../work.cpp" line="208"/>
        <location filename="../work.cpp" line="225"/>
        <location filename="../work.cpp" line="261"/>
        <location filename="../work.cpp" line="306"/>
        <location filename="../work.cpp" line="337"/>
        <source>Error</source>
        <translation type="unfinished">Klaida</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="35"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="56"/>
        <location filename="../work.cpp" line="63"/>
        <location filename="../work.cpp" line="69"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="57"/>
        <location filename="../work.cpp" line="64"/>
        <location filename="../work.cpp" line="70"/>
        <source>You have %1 free space on %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="95"/>
        <source>Cleaning...</source>
        <translation type="unfinished">Išvaloma...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="111"/>
        <location filename="../work.cpp" line="114"/>
        <source>Done</source>
        <translation type="unfinished">Atlikta</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="149"/>
        <source>Copying the new-iso filesystem...</source>
        <translation type="unfinished">Kopijuojama new-iso failų sistema...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="177"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="206"/>
        <source>Squashing filesystem...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="208"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">Nepavyko sukurti linuxfs failo, prašome patikrinti ar paskirties skaidinyje yra pakankamai vietos.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="223"/>
        <source>Creating CD/DVD image file...</source>
        <translation type="unfinished">Kuriamas CD/DVD atvaizdžio failas...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="225"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">Nepavyko sukurti ISO failo, prašome patikrinti ar paskirties skaidinyje yra pakankamai vietos.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="232"/>
        <source>Making hybrid iso</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="247"/>
        <source>Success</source>
        <translation type="unfinished">Pavyko</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="247"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="248"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="249"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="258"/>
        <source>Installing </source>
        <translation type="unfinished">Įdiegiama </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="261"/>
        <source>Could not install </source>
        <translation type="unfinished">Nepavyko įdiegti</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="271"/>
        <source>Calculating checksum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="306"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="315"/>
        <source>Building new initrd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="337"/>
        <source>Could not find %1 file, cannot continue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
